==> jmapc-0.2.0.tar.gz: jmapc-0.2.0/jmapc/models/__init__.py <==
from .email import (
    Email,
    EmailBodyPart,
    EmailBodyValue,
    EmailHeader,
    EmailQueryFilter,
    EmailQueryFilterCondition,
    EmailQueryFilterOperator,
)
from .email_submission import (
    Address,
    Delivered,
    DeliveryStatus,
    Displayed,
    EmailSubmission,
    EmailSubmissionQueryFilter,
    EmailSubmissionQueryFilterCondition,
    EmailSubmissionQueryFilterOperator,
    Envelope,
    UndoStatus,
)
from .event import Event, StateChange, TypeState
from .identity import Identity
from .mailbox import (
    Mailbox,
    MailboxQueryFilter,
    MailboxQueryFilterCondition,
    MailboxQueryFilterOperator,
)
from .models import (
    AddedItem,
    Comparator,
    EmailAddress,
    ListOrRef,
    Operator,
    SetError,
    StrOrRef,
)
from .thread import Thread, ThreadEmail

__all__ = [
    "AddedItem",
    "Address",
    "Comparator",
    "Delivered",
    "DeliveryStatus",
    "Displayed",
    "Email",
    "EmailAddress",
    "EmailBodyPart",
    "EmailBodyValue",
    "EmailHeader",
    "EmailQueryFilter",
    "EmailQueryFilterCondition",
    "EmailQueryFilterOperator",
    "EmailSubmission",
    "EmailSubmissionQueryFilter",
    "EmailSubmissionQueryFilterCondition",
    "EmailSubmissionQueryFilterOperator",
    "Envelope",
    "Event",
    "Identity",
    "ListOrRef",
    "Mailbox",
    "MailboxQueryFilter",
    "MailboxQueryFilterCondition",
    "MailboxQueryFilterOperator",
    "Operator",
    "SetError",
    "StateChange",
    "StrOrRef",
    "Thread",
    "ThreadEmail",
    "TypeState",
    "UndoStatus",
]

==> jmapc-0.2.4.tar.gz: jmapc-0.2.4/jmapc/models/__init__.py <==
from .email import (
    Email,
    EmailBodyPart,
    EmailBodyValue,
    EmailHeader,
    EmailQueryFilter,
    EmailQueryFilterCondition,
    EmailQueryFilterOperator,
)
from .email_submission import (
    Address,
    Delivered,
    DeliveryStatus,
    Displayed,
    EmailSubmission,
    EmailSubmissionQueryFilter,
    EmailSubmissionQueryFilterCondition,
    EmailSubmissionQueryFilterOperator,
    Envelope,
    UndoStatus,
)
from .event import Event, StateChange, TypeState
from .identity import Identity
from .mailbox import (
    Mailbox,
    MailboxQueryFilter,
    MailboxQueryFilterCondition,
    MailboxQueryFilterOperator,
)
from .models import (
    AddedItem,
    Comparator,
    EmailAddress,
    ListOrRef,
    Operator,
    SetError,
    StrOrRef,
)
from .thread import Thread

__all__ = [
    "AddedItem",
    "Address",
    "Comparator",
    "Delivered",
    "DeliveryStatus",
    "Displayed",
    "Email",
    "EmailAddress",
    "EmailBodyPart",
    "EmailBodyValue",
    "EmailHeader",
    "EmailQueryFilter",
    "EmailQueryFilterCondition",
    "EmailQueryFilterOperator",
    "EmailSubmission",
    "EmailSubmissionQueryFilter",
    "EmailSubmissionQueryFilterCondition",
    "EmailSubmissionQueryFilterOperator",
    "Envelope",
    "Event",
    "Identity",
    "ListOrRef",
    "Mailbox",
    "MailboxQueryFilter",
    "MailboxQueryFilterCondition",
    "MailboxQueryFilterOperator",
    "Operator",
    "SetError",
    "StateChange",
    "StrOrRef",
    "Thread",
    "TypeState",
    "UndoStatus",
]
